@@ -1,4 +1,4 @@
-# $Id: mvt.R 341 2018-05-31 08:29:12Z thothorn $
+# $Id: mvt.R 345 2019-02-28 12:28:59Z thothorn $
 
 ##' Do we have a correlation matrix?
 ##' @param x typically a matrix
@@ -482,7 +482,10 @@ qmvt <- function(p, interval = NULL,
     if (!is.null(sigma)) dim <- NROW(sigma)
     lower <- upper <- rep.int(0, dim)
     args <- checkmvArgs(lower, upper, delta, corr, sigma)
+    if (is.null(args$sigma)) args$sigma <- 1
     if (args$uni) {
+        if (!identical(args$sigma, 1))
+            stop("sigma != 1 not implemented for univariate case")
         if (tail == "both.tails") p <- ifelse(p < 0.5, p / 2, 1 - (1 - p)/2)
         if (df == 0 || isInf(df)) { # MH: now (also) properly allow df = Inf
             q <- qnorm(p, mean = args$mean, lower.tail = (tail != "upper.tail"))
